#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# JANGAN COPAS INI LU KEK KONTOL
# TANYA KE SUPPORT @KillerXSupport

from pyrogram import Client, filters
from pyrogram.types import Message
from base64 import b64decode
import requests
import base64

class CustomUrl:
    def __init__(
        self,
        url=None,
        website="mediafire"
    ):
        self.url = url
        self.website = website

    def tools_downloader(self):
        parameter = b64decode("aHR0cDovL2Rvd25sb2FkLnJhbmR5ZGV2Lm15Lmlk").decode("utf-8")
        api_url = f"{parameter}/{self.website}?link={self.url}"
        x = requests.get(api_url)
        if x.status_code != 200:
            return "Error request"
        try:
            response = x.json()
            download = response["data"]["file"]["url"]["directDownload"]
            author_username = response["data"]["file"]["metadata"]["id"]
            file_size = response["data"]["file"]["metadata"]["size"]["readable"]
            return [download, author_username, file_size]
        except Exception as e:
            return f"Error: {e}"



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

from datetime import datetime as dt, timedelta
from pytz import timezone

class Reminder:
    def __init__(
        self,
        days: int=None,
        timezone_str: str=None,
    ):
        self.days = days
        self.timezone_str = timezone_str
        self.timezone = timezone(timezone_str)

    async def warning_alert(self, check_break: bool=None):
        if check_break:
            now = dt.now(self.timezone)
            time = now.strftime("%d-%m-%Y")
            expire_date = now + timedelta(days=self.days)
            return [expire_date, time]
        else:
            return None



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

from pyrogram import Client, filters
from pyrogram.types import Message
from pyrogram import *
from pyrogram.types import *

@Client.on_message(filters.command("start"))
async def startwb(client: Client, message: Message):
    text = "Welcome to Ryuzaki Library"
    keyboard = [
        [
            InlineKeyboardButton(
                text="Ryuzaki Library",
                url="https://docs.randydev.my.id"
            )
        ]
    ]
    bttn = InlineKeyboardMarkup(keyboard)
    try:
        await client.send_message(
            message.chat.id,
            text=text,
            reply_markup=bttn,
            reply_to_message_id=message.id
        )
    except Exception as e:
        await message.reply_text(str(e))
        return



import os
import logging
import asyncio
from pyrogram import Client, filters
from pyrogram.types import Message
from buildbot.secrets.env import *

logging.getLogger("pyrogram").setLevel(logging.WARNING)
logging.basicConfig(level=logging.INFO)

LOGS = logging.getLogger(__name__)

def LOGGER(name: str) -> logging.Logger:
    return logging.getLogger(name)

if not TELEGRAM_TOKEN:
    print("Warning no bot token")

client = Client(
    "RyuzakiLib",
    api_id=API_ID,
    api_hash=API_HASH,
    bot_token=TELEGRAM_TOKEN,
    plugins=dict(root="buildbot.modules"),
    in_memory=True,
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# JANGAN COPAS INI LU KEK KONTOL
# TANYA KE SUPPORT @KillerXSupport

from base64 import b64decode
import requests
import base64
from io import BytesIO

class WebShotUrl:
    def __init__(
        self,
        url=None,
        base="aHR0cHM6Ly9hcGkuc2Fmb25lLmRldi93ZWJzaG90",
        width: int=1280,
        height: int=720,
        scale: int=1,
        delay: int=0,
        quality="1920x1080",
        type_mine="JPEG",
        pixels="1024",
        cast="Z100",
        author="@xtdevs"
    ):
        self.url = url
        self.width = width
        self.height = height
        self.scale = scale
        self.delay = delay
        self.quality = quality
        self.type_mine = type_mine
        self.pixels = pixels
        self.cast = cast
        self.author = author

    def send_screenshot_quality(self):
        try:
            required_url = f"https://mini.s-shot.ru/{self.quality}/{self.type_mine}/{self.pixels}/{self.cast}/?{self.url}"
            caption = f"Powered By {self.author}"
            return [required_url, caption]
        except Exception as e:
            return f"Error {e}"

    def send_screenshot(self, screenshot_full: bool=None):
        api_url = b64decode(self.base).decode("utf-8")
        if screenshot_full:
            data = {
                "url": self.url,
                "width": self.width,
                "height": self.height,
                "scale": self.scale,
                "delay": self.delay,
                "full": True
            }
            x = requests.post(f"{api_url}", json=data)
            if x.status_code != 200:
                return "Error request:"
            try:
                y = x.json()
                iseeyou = base64.b64decode(y["image"])
                hack = BytesIO(iseeyou)
                hack.name = "screenshot.jpg"
                return hack
            except Exception as e:
                return f"Error: {e}"
        else:
            data = {
                "url": self.url,
                "width": self.width,
                "height": self.height,
                "scale": self.scale,
                "delay": self.delay,
                "full": False
            }
            x = requests.post(f"{api_url}", json=data)
            if x.status_code != 200:
                return "Error request:"
            try:
                y = x.json()
                iseeyou = base64.b64decode(y["image"])
                hack = BytesIO(iseeyou)
                hack.name = "screenshot.jpg"
                return hack
            except Exception as e:
                return f"Error: {e}"



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import openai

class OpenAiToken:
    def __init__(self, apikey):
        self.apikey = apikey
        openai.api_key = self.apikey

    def message_output(self, query):
        response = openai.Completion.create(
            model="text-davinci-003",
            prompt=f"{query}\n:",
            temperature=0,
            max_tokens=500,
            top_p=1.0,
            frequency_penalty=0.0,
            presence_penalty=0.0,
        )
        return response.choices[0].text

    def photo_output(self, query):
        response = openai.Image.create(prompt=query, n=1, size="1024x1024")
        return response["data"][0]["url"]

    def audio_transcribe(self, file_path):
        with open(file_path, "rb") as path:
            transcript = openai.Audio.transcribe("whisper-1", path)
        return transcript



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# JANGAN COPAS INI LU KEK KONTOL
# TANYA KE SUPPORT @KillerXSupport

import os
import requests
from pyrogram import Client, filters
from pyrogram.types import Message
from base64 import b64decode

class ChatbotAi:
    def __init__(
        self,
        query,
        user_id: int=None,
        base="aHR0cHM6Ly9hcGkuc2Fmb25lLmRldi9jaGF0Ym90",
        bot_name="Ryuzaki Dev",
        bot_master="@Randydev_bot"
    ):
        self.query = query
        self.user_id = user_id
        self.base = base
        self.bot_name = bot_name
        self.bot_master = bot_master

    def get_response_ai(self):
        api_url = b64decode(self.base).decode("utf-8")
        params = {
            "query": self.query,
            "user_id": self.user_id,
            "bot_name": self.bot_name,
            "bot_master": self.bot_master
        }
        x = requests.get(f"{api_url}", params=params)
        if x.status_code != 200:
            return "Error api request"
        try:
            y = x.json()
            response = y["response"]
            return response
        except Exception as e:
            return f"Error {e}"



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


import requests

class QuoteRandom:
    endpoint_url = "https://api.quotable.io"
    def __init__(self):
        pass

    def get_results(self, parameter: str="/quotes/random", check_for: bool=None):
        api_url = self.endpoint_url
        response = requests.get(api_url + parameter)
        if response.status_code != 200:
            return f"Error status {response.status_code}"
        results = response.json()
        if check_for:
            for x in results:
                return x
        else:
            return results



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import requests
from pyrogram import Client, filters
from pyrogram.types import Message
import base64
from base64 import b64decode as idk
import os
import json

class RendyDevChat:
    def __init__(
        self,
        query,
        binary="01101000 01110100 01110100 01110000 01110011 00111010 00101111 00101111 01100001 01110000 01101001 00101110 01110011 01100001 01100110 01101111 01101110 01100101 00101110 01100100 01100101 01110110 00101111 01100011 01101000 01100001 01110100 01100111 01110000 01110100",
    ):
        self.query = query
        self.binary = binary

    @staticmethod
    def knowledge_hack(text_code):
        you_dont_know = "".join(text_code)
        number = you_dont_know.split()
        return "".join(chr(int(binary, 2)) for binary in number)

    def get_blacklist_from_file(self):
        try:
            with open("blacklist.json", "r") as file:
                blacklist = json.load(file)
            return set(blacklist)
        except FileNotFoundError:
            return set()

    def get_response(
        self,
        message,
        version: int=3,
        chat_mode: str="assistant",
        latest_version: bool=None
    ):
        if isinstance(message, Message):
            blacklist = self.get_blacklist_from_file()
            if message.from_user.id in blacklist:
                return "Blocked User"
        if latest_version:
            response_url = self.knowledge_hack(self.binary)
            payloads = {
                "message": self.query,
                "version": version,
                "chat_mode": chat_mode,
                "dialog_messages": "[{'bot': '', 'user': ''}]"
            }
            try:
                response = requests.post(
                    f"{response_url}",
                    json=payloads,
                    headers={"Content-Type": "application/json"}
                ).json()
                if not (response and "message" in response):
                    print(response)
                    raise ValueError("Invalid Response from Server")
                return response.get("message")
            except Exception as e:
                return f"Error Api {e}"
        else:
            return f"WTF THIS {self.query}"



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

from pyrogram import Client, filters
from pyrogram.types import Message

class CustomPrefixes:
    def __init__(self, name, user_id, prefix, collection, value: bool):
        self.name = name
        self.prefix = prefix
        self.user_id = user_id
        self.collection = collection
        self.value = value

    def add_prefixes(self):
        add_handler = {f"{self.name}": self.prefix}
        return self.collection.update_one(
            {"user_id": self.user_id},
            {"$set": add_handler},
            upsert=self.value
        )
    def get_prefix(self):
        user_data = self.collection.find_one({"user_id": self.user_id})
        return user_data.get(f"{self.name}") if user_data else None



import asyncio
import importlib
from pyrogram import Client, idle
from buildbot import client

async def start_bot():
    try:
        await client.start()
        ur = await client.get_me()
        print(f"Started {ur.first_name}")
    except Exception as e:
        print(f"{e}")
    await idle()

loop = asyncio.get_event_loop()
loop.run_until_complete(start_bot())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

from typing import Union
from pyrogram import Client

class Stories:
    def __init__(self):
        pass

    async def get_story(
        self,
        client: Client,
        from_id: Union[int, str] = None,
        story_ids: Union[int, list] = None
    ):
        if isinstance(client, Client):
            user = await client.get_stories(from_id=from_id, story_ids=story_ids)
            return user

    async def export_link(
        self,
        client: Client,
        from_id: Union[int, str] = None,
        story_id: int = None
    ):
        if isinstance(client, Client):
            user = await client.export_story_link(from_id=from_id, story_id=story_id)
            return user

    async def get_all_story(self, client: Client):
        if isinstance(client, Client):
            async for story in client.get_all_stories():
                return story



from pyrogram import Client, filters
from pyrogram.types import Message
from typing import Union

class ChannelCopy:
    def __init__(
        self,
        client: Client,
        chat_id: Union[str, int] = None
    ):
        self.client = client
        self.chat_id = chat_id

    async def download(
        self,
        message_id: int = None,
        faster: bool = False,
        to_forward: bool = False
    ) -> Union[Tuple[str, str], Message, str]:
        try:
            if faster:
                processed = await self.client.get_messages(chat_id=self.chat_id, message_ids=message_id)
                photo_or_video = await processed.download()
                return [photo_or_video, processed.caption]
            elif to_forward:
                processed = await self.client.get_messages(chat_id=self.chat_id, message_ids=message_id)
                return await processed.forward(self.chat_id)
            else:
                return "Please use required to_forward: boolean"
        except Exception as e:
            return f"Error: {e}"



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>

import os

class OpenReadSystem:
    def __init__(
        self,
        code_system: str=None
    ):
        self.code_system = code_system

    def show(self, read_system: bool=None):
        if read_system:
            res = os.popen(self.code_system).read()
            return res
        else:
            res = os.popen(self.code_system)
            return res

    def remover(self):
        return os.remove(self.code_system)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import requests

class FullStackDev:
    def __init__(
        self,
        domain_url: str=None,
        headers=None,
        params: str=None,
        json_data=None,
        type_mode: str="wb",
        filename: str=None
    ):
        self.headers = headers
        self.domain_url = domain_url
        self.params = params
        self.json_data = json_data
        self.type_mode = type_mode
        self.filename = filename

    def domain_urls(self):
        request_url = self.domain_url
        return request_url

    def ryuzaki_get(self, re_json: bool=None):
        request_url = self.domain_urls()
        if re_json:
            req = requests.get(request_url, headers=self.headers, params=self.params).json()
            return req
        else:
            req = requests.get(request_url, headers=self.headers, params=self.params)
            return req

    def ryuzaki_post(self, re_json: bool=None):
        request_url = self.domain_urls()
        if re_json:
            req = requests.post(request_url, headers=self.headers, params=self.json_data).json()
            return req
        else:
            req = requests.post(request_url, headers=self.headers, json=self.json_data)
            return req

    def faster_downloader(self):
        request_url = self.domain_urls()
        req = requests.get(request_url, allow_redirects=True)
        with open(self.filename, self.type_mode) as file:
            file.write(req.content)
        return self.filename

    def fastapi_get(self, re_json: bool=None):
        request_url = self.domain_urls()
        if re_json:
            req = requests.get(request_url, headers=self.headers, params=self.json_data).json()
            if req.status_code != 200:
                return "Not Responding"
            try:
                return req
            except Exception as e:
                return {"status": "false", "message": f"error {e}"}
        else:
            req = requests.get(request_url, headers=self.headers, json=self.json_data)
            if req.status_code != 200:
                return "Not Responding"
            try:
                return req
            except Exception as e:
                return {"status": "false", "message": f"error {e}"}



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

from pyrogram import Client, filters
from pyrogram.types import Message
from pyrogram import *
from pyrogram.types import *

from RyuzakiLib.extreme.chatbot import ChatbotAi

@Client.on_message(filters.text & filters.private)
async def chatbot_assistant(client: Client, message: Message):
    if message.text:
        text = message.text
        chat_id = message.chat.id
        user_id = message.from_user.id
        try:
            code = ChatbotAi(query=text, user_id=user_id)
            response = code.get_response_ai()
            await client.send_message(
                chat_id,
                text=response,
                reply_to_message_id=message.id
            )
        except Exception as e:
            await message.reply_text(str(e))
            return



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import requests
from io import BytesIO
from aiohttp import ClientSession
from pyrogram import Client, filters
from pyrogram.types import Message

aiosession = ClientSession()

class CarbonSuper:
    def __init__(
        self,
        code,
        color=None,
    ):
        self.code = code
        self.color = color

    async def make_carbon(self, ryuzaki: bool=None):
        url = "https://carbonara.solopov.dev/api/cook"
        if ryuzaki:
            async with aiosession.post(url, json={"code": self.code, "backgroundColor": self.color}) as resp:
                image = BytesIO(await resp.read())
            image.name = "carbon.png"
            return image
        else:
            async with aiosession.post(url, json={"code": self.code}) as resp:
                image = BytesIO(await resp.read())
            image.name = "carbon.png"
            return image



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pipenv install twine --dev

import io
import os
import sys
import re
from shutil import rmtree

from setuptools import find_packages, setup, Command

def my_test_suite():
    import unittest
    test_loader = unittest.TestLoader()
    return test_loader.discover('tests', pattern='test*.py')

with open("RyuzakiLib/__init__.py", encoding="utf-8") as f:
    version = re.findall(r"__version__ = \"(.+)\"", f.read())[0]


with open("README.md", encoding="utf-8") as f:
    readme = f.read()

with open("requirements.txt", encoding="utf-8") as r:
    requires = [i.strip() for i in r]


class UploadCommand(Command):
    """Support setup.py upload."""

    description = 'Build and publish the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        self.status('installation requirements..')
        os.system('pip3 install -e .')

        self.status('Minimally you should create a Source Distribution:...')
        os.system('python3 setup.py sdist')

        self.status('Building Source and Wheel (universal) distribution…')
        os.system('python3 setup.py bdist_wheel --universal')

        self.status('Uploading the package to PyPI via Twine…')
        os.system('twine upload dist/*')

        self.status('Pushing git tags…')
        os.system('git tag v{0}'.format(version))
        os.system('git push --tags')

        sys.exit()


project_urls = {
    "Bug Tracker": "https://github.com/TeamKillerX/RyuzakiLib/issues",
    "Documentation": "https://docs.randydev.my.id/",
    "Source Code": "https://github.com/TeamKillerX/RyuzakiLib",
}

setup(
    name="RyuzakiLib",
    version=version,
    description="RyuzakiLib Powerfull base on Pyrogram",
    long_description=readme,
    long_description_content_type='text/markdown',
    author="TeamKillerX",
    author_email="killerx@randydev.my.id",
    python_requires="~=3.7",
    url="https://github.com/TeamKillerX/RyuzakiLib/",
    project_urls=project_urls,
    packages=find_packages(exclude=["tests", "*.tests", "*.tests.*", "tests.*"]),
    test_suite="setup.my_test_suite",

    install_requires=requires,
    include_package_data=True,
    license='MIT',
    zip_safe=False,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: Implementation",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Internet",
        "Topic :: Communications",
        "Topic :: Communications :: Chat",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Libraries :: Application Frameworks"
    ],
    cmdclass={
        'upload': UploadCommand,
    },
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


from pyrogram import Client, filters
from pyrogram.types import Message
from httpx import AsyncClient
import os

class GithubUsername:
    def __init__(self, username):
        self.username = username

    async def get_github_data(self):
        base_msg = ""
        async with AsyncClient() as gpx:
            req = (await gpx.get(f"https://api.github.com/users/{self.username}")).json()
            try:
                avatar = req["avatar_url"]
                twitter = req['twitter_username']
                base_msg += "**❆ Gitub Information ❆** \n\n"
                base_msg += f"**Profile Url:** {req['html_url']} \n"
                base_msg += f"**Name:** `{req['name']}` \n"
                base_msg += f"**Username:** `{req['login']}` \n"
                base_msg += f"**User ID:** `{req['id']}` \n"
                base_msg += f"**Location:** `{req['location']}` \n"
                base_msg += f"**Company:** `{req['company']}` \n"
                base_msg += f"**Blog:** `{req['name']}` \n"
                base_msg += f"**Twitter:** `{f'https://twitter.com/{twitter}' if twitter else 'None'}` \n"
                base_msg += f"**Bio:** `{req['bio']}` \n"
                base_msg += f"**Public Repos:** `{req['public_repos']}` \n"
                base_msg += f"**Public Gists:** `{req['public_gists']}` \n"
                base_msg += f"**Followers:** `{req['followers']}` \n"
                base_msg += f"**Following:** `{req['following']}` \n"
                base_msg += f"**Created At:** `{req['created_at']}` \n"
                base_msg += f"**Update At:** `{req['updated_at']}` \n"
                return [base_msg, avatar]
            except Exception as e:
                base_msg += f"**An error occured while parsing the data!** \n\n**Traceback:** \n `{e}` \n\n`Make sure that you've sent the command with the correct username!`"
                return [base_msg, "https://telegra.ph//file/32f69c18190666ea96553.jpg"]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

from pyrogram import Client, filters
from pyrogram.types import Message
import requests
from random import choice

class SendWaifuRandom:
    def __init__(self):
        pass

    def send_waifu_pics(self):
        LIST_SFW_JPG = ["neko", "waifu", "megumin"]
        waifu_api = "https://api.waifu.pics/sfw"
        waifu_category = choice(LIST_SFW_JPG)
        waifu_param = f"{waifu_api}/{waifu_category}"

        response = requests.get(waifu_param)

        if response.status_code != 200:
            return "Sorry, there was an error processing your request. Please try again later"

        data_waifu = response.json()
        try:
            waifu_image_url = data_waifu["url"]
        except Exception as e:
            return f"Error request {e}"

        if waifu_image_url:
            try:
                return waifu_image_url
            except Exception as e:
                return f"**Info Error:** {e}"
        else:
            return "Not found waifu"



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

# JANGAN COPAS INI LU KEK KONTOL
# TANYA KE SUPPORT @KillerXSupport

from base64 import b64decode
import requests
import base64
from io import BytesIO

from gpytranslate import SyncTranslator

class CarbonRaySo:
    def __init__(
        self,
        code=None,
        title="Ryuzaki Dev",
        theme=None,
        setlang="en",
        base="aHR0cHM6Ly9hcGkuc2Fmb25lLmRldi9yYXlzbw=="
    ):
        self.code = code
        self.title = title
        self.theme = theme
        self.setlang = setlang
        self.base = base

    def make_carbon_rayso(
        self,
        auto_translate: bool=None,
        check_sticker: bool=None,
        darkmode: bool=None,
        ryuzaki: bool=None
    ):
        trans = SyncTranslator()
        api_url = b64decode(self.base).decode("utf-8")
        if check_sticker:
            filename = "rayso.webp"
        else:
            filename = "rayso.jpg"
        if auto_translate:
            source = trans.detect(self.code)
            translation = trans(self.code, sourcelang=source, targetlang=self.setlang)
            code = translation.text
        else:
            code = self.code
        if ryuzaki:
            x = requests.post(
                f"{api_url}",
                json={
                    "code": code,
                    "title": self.title,
                    "theme": self.theme,
                    "darkMode": darkmode
                }
            )
            if x.status_code != 200:
                return "Error api Gay"
            data = x.json()
            try:
                image_data = base64.b64decode(data["image"])
                f = BytesIO(image_data)
                f.name = filename
                return f
            except Exception as e:
                return f"Error: {e}"
        else:
            x = requests.post(
                f"{api_url}",
                json={
                    "code": code,
                    "title": self.title,
                    "theme": "breeze",
                    "darkMode": darkmode
                }
            )
            if x.status_code != 200:
                return "Error api Gay"
            data = x.json()
            try:
                image_data = base64.b64decode(data["image"])
                f = BytesIO(image_data)
                f.name = filename
                return f
            except Exception as e:
                return f"Error: {e}"



# Copyright (C) 2020-2023 TeamKillerX <https://github.com/TeamKillerX>
#
# This file is part of TeamKillerX project,
# and licensed under GNU Affero General Public License v3.
# See the GNU Affero General Public License for more details.
#
# All rights reserved. See COPYING, AUTHORS.
#
# Developer Credits: @xtdevs

import requests
import os
import time
from pyrogram import Client, filters
from pyrogram.types import Message
from tqdm import tqdm


class FacebookUrl:
    def __init__(self, apikey, link):
        self.apikey = apikey
        self.link = link

    def facebook_downloader(self):
        url = "https://facebook-video-and-reel-downloader.p.rapidapi.com/"
        querystring = {"url": self.link}

        headers = {"X-RapidAPI-Key": self.apikey, "X-RapidAPI-Host": "facebook-video-and-reel-downloader.p.rapidapi.com"}
        response = requests.request("GET", url, headers=headers, params=querystring)

        if response.status_code != 200:
            return "Error requests api"
        data_facebook = response.json()
        try:
            facebook_hd = data_facebook["sd"]
        except Exception as e:
            return f"Error request {e}"

        facebook_url = requests.get(facebook_hd, stream=True)
        if not facebook_hd:
            return "Error please try again facebook"
        if not facebook_url:
            return "Error please try again"
        total_size = int(facebook_url.headers.get("content-length", 0))
        send_video_path = "ryuzaki.mp4"
        progress_bar = ""
        with open(send_video_path, "wb") as f:
            bytes_received = 0
            progress = 0
            for data in facebook_url.iter_content(chunk_size=4096):
                f.write(data)
                bytes_received += len(data)
                progress = int(bytes_received / total_size * 100)
                new_progress_bar = f"Downloading {progress}% of {total_size}"
                if new_progress_bar != progress_bar:
                    return new_progress_bar
        return send_video_path



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


import requests
import os
from pyrogram import Client, filters
from pyrogram.types import Message

from RyuzakiLib.api.fullstack import FullStackDev

class TiktokUrl:
    def __init__(
        self,
        url
    ):
        self.url = url

    def tiktok_downloader(self, ryuzaki: bool=None):
        tiktok_url = self.url
        api_devs = "https://api.sdbots.tech"
        parameter = f"tiktok?url={tiktok_url}"
        api_url = f"{api_devs}/{parameter}"
        response = requests.get(api_url)

        if response.status_code != 200:
            return "Error: Unable to fetch data from the TikTok API"

        try:
            results = response.json()
            caption = results.get("result", {}).get("desc", "")

            if ryuzaki:
                video_url = results.get("result", {}).get("withoutWaterMarkVideo", "")
                if video_url:
                    return [video_url, caption]
            else:
                music_mp3 = results.get("result", {}).get("music", "")
                if music_mp3:
                    return [music_mp3, caption]

            return "Error: TikTok data not found or unsupported format"
        except Exception as e:
            return f"Error: {e}"

def faster_tiktok_downloader(link: str=None, ryuzaki_default: str="ryuzaki.mp4"):
    if not link:
        return "Missing Tiktok Link"
    try:
        obj = TiktokUrl(url=link).tiktok_downloader(ryuzaki=True)
        super = FullStackDev(
            domain_url=obj[0],
            filename=ryuzaki_default,
            type_mode="wb"
        )
        saved = super.faster_downloader()
        return saved
    except Exception as e:
        return f"Error: {e}"



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2020-2023 (c) Randy W @xtdevs, @xtsea
#
# from : https://github.com/TeamKillerX
# Channel : @RendyProjects
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


from pyrogram import Client, filters
from pyrogram.types import Message
import json
import requests

class OcrApiUrl:
    def __init__(self, api_key, url, language):
        self.api_key = api_key
        self.url = url
        self.language = language

    def ocr_space_url(self, overlay=False):
        payload = {
            "url": self.url,
            "isOverlayRequired": overlay,
            "apikey": self.api_key,
            "language": self.language
        }
        try:
            response = requests.post("https://api.ocr.space/parse/image", data=payload)
            response.raise_for_status()
            return response.content.decode()
        except requests.exceptions.RequestException as e:
            return f"Error: {str(e)}"

    def now_send_text(self):
        try:
            test_url = self.ocr_space_url()
            parsed_response = json.loads(test_url)
            if "ParsedResults" in parsed_response and len(parsed_response["ParsedResults"]) > 0:
                return parsed_response["ParsedResults"][0]["ParsedText"]
            else:
                return "No text found in the image."
        except (json.JSONDecodeError, KeyError):
            return "Error parsing the OCR response."
